@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
-# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# Copyright (C) 2020-2021, Yoel Cortes-Pena <yoelcortes@gmail.com>
 # 
 # This module is under the UIUC open-source license. See 
 # github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
@@ -47,15 +47,15 @@ class Settings:
         """
         Return a default Thermo object.
         If `thermo` is a Thermo object, return the same object.
+        
         """
-        if not thermo:
-            thermo = self.get_thermo()
-        return thermo
+        return thermo if thermo else self.get_thermo()
     
     def get_default_chemicals(self, chemicals):
         """
         Return a default CompiledChemicals object.
         If `chemicals` is a Chemicals object, return the same object.
+        
         """
         if isinstance(chemicals, tmo.Chemicals):
             chemicals.compile()
@@ -71,6 +71,7 @@ class Settings:
         """
         Return a default Mixture object.
         If `mixture` is a Mixture object, return the same object.
+        
         """
         if not mixture:
             thermo = settings.thermo
@@ -84,7 +85,7 @@ class Settings:
         if not thermo: raise_no_thermo_error()
         return thermo
     
-    def set_thermo(self, thermo, cache=None):
+    def set_thermo(self, thermo, cache=None, skip_checks=False):
         """
         Set the default Thermo object. If `thermo` is not a Thermo object,
         an attempt is made to convert it to one.
@@ -95,10 +96,12 @@ class Settings:
             A Thermo object or iterable of chemicals or chemical IDs.
         cache : bool, optional
             Wether or not to use cached chemicals.
+        skip_checks : bool, optional
+            Whether to skip checks for missing or invalid properties.
             
         """
         if not isinstance(thermo, tmo.Thermo):
-            thermo = tmo.Thermo(thermo, cache=cache)
+            thermo = tmo.Thermo(thermo, cache=cache, skip_checks=skip_checks)
         self._thermo = thermo
     
     def get_chemicals(self):
