@@ -8,6 +8,7 @@
 """
 """
 import flexsolve as flx
+from warnings import warn
 from ..exceptions import InfeasibleRegion
 from . import binary_phase_fraction as binary
 from .equilibrium import Equilibrium
@@ -254,24 +255,24 @@ class VLE(Equilibrium, phases='lg'):
         # Run equilibrium
         if T_spec:
             if P_spec:
-                return self.set_thermal_condition(T, P)
+                self.set_thermal_condition(T, P)
             elif V_spec:
-                return self.set_TV(T, V)
+                self.set_TV(T, V)
             elif H_spec:
-                return self.set_TH(T, H)
+                self.set_TH(T, H)
             elif x_spec:
-                return self.set_Tx(T, np.asarray(x))
+                self.set_Tx(T, np.asarray(x))
             else: # y_spec
-                return self.set_Ty(T, np.asarray(y))
+                self.set_Ty(T, np.asarray(y))
         elif P_spec:
             if V_spec:
-                return self.set_PV(P, V)
+                self.set_PV(P, V)
             elif H_spec:
-                return self.set_PH(P, H)
+                self.set_PH(P, H)
             elif x_spec:
-                return self.set_Px(P, np.asarray(x))
+                self.set_Px(P, np.asarray(x))
             else: # y_spec
-                return self.set_Py(P, np.asarray(y))
+                self.set_Py(P, np.asarray(y))
         elif H_spec: # pragma: no cover
             if y_spec:
                 raise NotImplementedError('specification H and y is invalid')
@@ -354,17 +355,29 @@ class VLE(Equilibrium, phases='lg'):
         
     def _set_thermal_condition_chemical(self, T, P):
         # Either liquid or gas
-        if P < self._chemical.Psat(T):
+        Psat = self._chemical.Psat(T)
+        tol = 1e-3
+        if P < Psat - tol:
             self._liquid_mol[self._index] = 0
             self._vapor_mol[self._index] = self._mol_vle
-        else:
+        elif P > Psat + tol:
             self._liquid_mol[self._index] = self._mol_vle
             self._vapor_mol[self._index] = 0
+        else:
+            pass
+            # raise RuntimeError(
+            #     'VLE of a one component mixture at the bubble point '
+            #     '(which is also the dew point) results in an undetermined '
+            #     'vapor fraction'
+            # )
+            # L_over_F = (P - Psat + tol) / (2 * tol)
+            # self._liquid_mol[self._index] = liq = L_over_F * self._mol_vle
+            # self._vapor_mol[self._index] = self._mol_vle - liq
     
     def _set_TV_chemical(self, T, V):
         # Set vapor fraction
         self._T = self._thermal_condition.T = self._chemical.Psat(T)
-        self._vapor_mol[self._index] = self._mol_vle*V
+        self._vapor_mol[self._index] = V * self._mol_vle
         self._liquid_mol[self._index] = self._mol_vle - self._vapor_mol[self._index]
         
     def _set_PV_chemical(self, P, V):
@@ -795,8 +808,11 @@ class VLE(Equilibrium, phases='lg'):
                            checkiter=False, 
                            checkconvergence=False, 
                            convergenceiter=3)
-        self._v = self._F_mol * self._V * y
-        return self._v
+        self._v = v = self._F_mol * self._V * y
+        mask = v > self._mol_vle
+        v[mask] = self._mol_vle[mask]
+        v[v < 0.] = 0.
+        return v
 
 class VLECache(Cache): load = VLE
 del Cache, Equilibrium
\ No newline at end of file
